@@ -9,13 +9,12 @@ class Template(CreateSendBase):
     self.template_id = template_id
     super(Template, self).__init__()
 
-  def create(self, client_id, name, html_url, zip_url, screenshot_url):
+  def create(self, client_id, name, html_url, zip_url):
     """Creates a new email template."""
     body = { 
       "Name": name,
       "HtmlPageURL": html_url,
-      "ZipFileURL": zip_url,
-      "ScreenshotURL": screenshot_url }
+      "ZipFileURL": zip_url }
     response = self._post("/templates/%s.json" % client_id, json.dumps(body))
     return json_to_py(response)
 
@@ -24,13 +23,12 @@ class Template(CreateSendBase):
     response = self._get("/templates/%s.json" % self.template_id)
     return json_to_py(response)
 
-  def update(self, name, html_url, zip_url, screenshot_url):
+  def update(self, name, html_url, zip_url):
     """Updates this email template."""
     body = {
       "Name": name,
       "HtmlPageURL": html_url,
-      "ZipFileURL": zip_url,
-      "ScreenshotURL": screenshot_url }
+      "ZipFileURL": zip_url }
     response = self._put("/templates/%s.json" % self.template_id, json.dumps(body))
 
   def delete(self):
